@@ -18,7 +18,7 @@ from expiringdict import ExpiringDict
 from pylav._logging import getLogger
 from pylav.constants import BUNDLED_NODES_IDS, PYLAV_NODES, REGION_TO_COUNTRY_COORDINATE_MAPPING, SUPPORTED_SOURCES
 from pylav.events import Event
-from pylav.exceptions import Unauthorized
+from pylav.exceptions import Unauthorized, WebsocketNotConnectedError
 from pylav.filters import (
     ChannelMix,
     Distortion,
@@ -230,6 +230,35 @@ class Node:
         Whether to use a ssl connection.
     """
 
+    __slots__ = (
+        "_query_cls",
+        "_manager",
+        "_session",
+        "_temporary",
+        "_host",
+        "_port",
+        "_password",
+        "_name",
+        "_ssl",
+        "_config",
+        "_managed",
+        "_region",
+        "_extras",
+        "_stats",
+        "_disabled_sources",
+        "_identifier",
+        "_resume_key",
+        "_resume_timeout",
+        "_reconnect_attempts",
+        "_search_only",
+        "_sources",
+        "_capabilities",
+        "_coordinates",
+        "_down_votes",
+        "_ready",
+        "_ws",
+    )
+
     def __init__(
         self,
         manager: NodeManager,
@@ -310,25 +339,33 @@ class Node:
             next_run_time=datetime.datetime.now(tz=datetime.timezone.utc) + datetime.timedelta(seconds=15),
         )
 
+    async def _unhealthy(self):
+        del self.down_votes
+        if self._ws is not None:
+            await self.websocket.manual_closure(
+                managed_node=self.identifier == self.node_manager.client.bot.user.id and self.websocket is not None
+            )
+        if self.identifier == self.node_manager.client.bot.user.id:
+            await self.node_manager.client.managed_node_controller.restart()
+            with contextlib.suppress(Exception):
+                await self.close()
+
     async def node_monitor_task(self):
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
+            try:
+                await self.websocket.ping()
+                LOGGER.trace("Node %s is healthy", self.name)
+            except (WebsocketNotConnectedError, ConnectionResetError):
+                LOGGER.warning("Node %s is unhealthy - Triggering a state reset", self.name)
+                await self._unhealthy()
+
             playing_players = len(self.playing_players)
             if playing_players == 0:
                 return
             if (self.down_votes / playing_players) >= 0.5:
-                del self.down_votes
-
-                if self._ws is not None:
-                    await self.websocket.manual_closure(
-                        managed_node=self.identifier == self.node_manager.client.bot.user.id
-                        and self.websocket is not None
-                    )
-                if self.identifier == self.node_manager.client.bot.user.id:
-                    await self.node_manager.client.managed_node_controller.restart()
-                    with contextlib.suppress(Exception):
-                        await self.close()
+                await self._unhealthy()
 
     @property
     def is_ready(self) -> bool:
@@ -776,21 +813,21 @@ class Node:
         :class:`dict`
             A dict representing tracks.
         """
-        if not bypass_cache and (response := await self.node_manager.client.query_cache_manager.get_query(query)):
+        if not bypass_cache and (response := await self.node_manager.client.query_cache_manager.fetch_query(query)):
             return typing.cast(
                 LavalinkResponseT,
-                {"track": response.tracks[0]}
+                {"track": await response.fetch_first()}
                 if first
                 else {
                     "playlistInfo": {
-                        "name": response.name,
+                        "name": await response.fetch_name(),
                     },
                     "loadType": "PLAYLIST_LOADED"
                     if query.is_playlist or query.is_album
                     else "SEARCH_RESULT"
                     if query.is_search
                     else "TRACK_LOADED",
-                    "tracks": [{"track": track} async for track in AsyncIter(response.tracks)],
+                    "tracks": [{"track": track} async for track in AsyncIter(await response.fetch_tracks())],
                 },
             )
 
